# Organization Modeling Guidelines
### On this page
  * [Definition](https://help.sap.com/docs/leanix/ea/organization-modeling-guidelines#definition)
  * [Description](https://help.sap.com/docs/leanix/ea/organization-modeling-guidelines#description)
  * [Organizations Fact Sheet Subtypes](https://help.sap.com/docs/leanix/ea/organization-modeling-guidelines#organizations-fact-sheet-subtypes)
  * [Guidelines and Best Practices](https://help.sap.com/docs/leanix/ea/organization-modeling-guidelines#guidelines-and-best-practices)
  * [How to Model Organization Organized Based on Regions and Business Units](https://help.sap.com/docs/leanix/ea/organization-modeling-guidelines#how-to-model-organization-organized-based-on-regions-and-business-units)
  * [How to Model Organization Structured by Regions Only](https://help.sap.com/docs/leanix/ea/organization-modeling-guidelines#how-to-model-organization-structured-by-regions-only)
  * [Antipatterns](https://help.sap.com/docs/leanix/ea/organization-modeling-guidelines#antipatterns)
  * [Applicable Use Cases](https://help.sap.com/docs/leanix/ea/organization-modeling-guidelines#applicable-use-cases)


View all
Learn how to model organizations. This includes best practices and applicable use cases, and common antipatterns.
**Note**
These modeling guidelines are for the meta model v4. For meta model v3 guidelines, see [Modeling: User Group](https://help.sap.com/docs/leanix/ea/user-group-modeling-v3?locale=en-US&state=PRODUCTION&version=CLOUD "The User Group Fact Sheet is an essential part of LeanIX's approach to representing business architecture. Often customers use it combined either with Business Capabilities or with Processes to obtain an Application Matrix report which is perfectly suited to identify possible synergies or gaps in the application landscape.").
